{% load i18n horizon humanize %}

{% block help_message %}
<h4>{% blocktrans %}Job{% endblocktrans %}</h4>

<p>{% blocktrans %}Specify the details for creating a job.{% endblocktrans %}</p>

<p>{% blocktrans %}A job defines an ordered list of actions to be executed in a client with scheduling information.{% endblocktrans %}</p>


{% endblock %}