{% load i18n horizon humanize %}

{% block help_message %}

<h4>{% blocktrans %}Rules{% endblocktrans %}</h4>

<p>{% blocktrans %}Define rules for this action, from how many times it will retry the action, the interval
    between interval and whether or not the action is mandatory. {% endblocktrans %}</p>

{% endblock %}

