{% load i18n horizon humanize %}

{% block help_message %}
<h4>{% blocktrans %}Start and End Date Time{% endblocktrans %}</h4>
<p>{% blocktrans %}Set a start date and time to execute jobs{% endblocktrans %}</p>

<h4>{% blocktrans %}Interval{% endblocktrans %}</h4>
<p>{% blocktrans %}Set the interval in the following format:{% endblocktrans %}</p>
    <ul>
        <li>continuous</li>
        <li>N weeks</li>
        <li>N days</li>
        <li>N hours</li>
        <li>N minutes</li>
        <li>N seconds</li>
    </ul>
<p>{% blocktrans %}If no start date is provided the job will start immediately{% endblocktrans %}</p>


<script type='text/javascript' src='{{ STATIC_URL }}freezer/js/vendor/moment.js'></script>
<script type='text/javascript' src='{{ STATIC_URL }}freezer/js/vendor/bootstrap-datetimepicker.js'></script>
<script type='text/javascript' src='{{ STATIC_URL }}freezer/js/freezer.datetimepicker.js'></script>

{% endblock %}