{% load i18n horizon humanize %}

{% block help_message %}
<h4>{% blocktrans %}Session{% endblocktrans %}</h4>

<p>{% blocktrans %}Specify the name for this session.{% endblocktrans %}</p>

<p>{% blocktrans %}A session is a collection of jobs which share scheduling information and will coordinate one
    or more clients.{% endblocktrans %}</p>


{% endblock %}