{% extends 'base.html' %}

{% block css %}
  {% include "_stylesheets.html" %}
  <link href='{{ STATIC_URL }}freezer/css/freezer.css' type='text/css' media='screen' rel='stylesheet' />
{% endblock %}

{% load i18n %}
{% block title %}{% trans "Clients" %}{% endblock %}

{% block page_header %}
  {% include "horizon/common/_page_header.html" with title=_("Clients") %}
{% endblock page_header %}

{% block main %}
  {{ table.render }}
{% endblock %}